==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_functions/mp0306_001/MP0306_AddPositionEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp0306_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.positionequipment_001.PositionEquipment;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PositionEquipment_001}PositionEquipment"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PositionEquipment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_availability_status" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="confirmaddlinearreferences" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       &lt;attribute name="confirmnewequipmentlength" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "positionEquipment"
})
@XmlRootElement(name = "MP0306_AddPositionEquipment_001")
public class MP0306_AddPositionEquipment_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "PositionEquipment", namespace = "http://schemas.datastream.net/MP_entities/PositionEquipment_001", required = true)
    protected PositionEquipment positionEquipment;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_availability_status")
    protected String confirm_Availability_Status;
    @XmlAttribute(name = "confirmaddlinearreferences")
    protected String confirmaddlinearreferences;
    @XmlAttribute(name = "confirmnewequipmentlength")
    protected String confirmnewequipmentlength;

    /**
     * Obtient la valeur de la propriété positionEquipment.
     * 
     * @return
     *     possible object is
     *     {@link PositionEquipment }
     *     
     */
    public PositionEquipment getPositionEquipment() {
        return positionEquipment;
    }

    /**
     * Définit la valeur de la propriété positionEquipment.
     * 
     * @param value
     *     allowed object is
     *     {@link PositionEquipment }
     *     
     */
    public void setPositionEquipment(PositionEquipment value) {
        this.positionEquipment = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.POSITION_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Availability_Status.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Availability_Status() {
        return confirm_Availability_Status;
    }

    /**
     * Définit la valeur de la propriété confirm_Availability_Status.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Availability_Status(String value) {
        this.confirm_Availability_Status = value;
    }

    /**
     * Obtient la valeur de la propriété confirmaddlinearreferences.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmaddlinearreferences() {
        return confirmaddlinearreferences;
    }

    /**
     * Définit la valeur de la propriété confirmaddlinearreferences.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmaddlinearreferences(String value) {
        this.confirmaddlinearreferences = value;
    }

    /**
     * Obtient la valeur de la propriété confirmnewequipmentlength.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmnewequipmentlength() {
        return confirmnewequipmentlength;
    }

    /**
     * Définit la valeur de la propriété confirmnewequipmentlength.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmnewequipmentlength(String value) {
        this.confirmnewequipmentlength = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp0306_001/MP0306_AddPositionEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp0306_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.positionequipment_001.PositionEquipment;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/PositionEquipment_001}PositionEquipment"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PositionEquipment" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="confirm_availability_status" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       <attribute name="confirmaddlinearreferences" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *       <attribute name="confirmnewequipmentlength" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "positionEquipment"
})
@XmlRootElement(name = "MP0306_AddPositionEquipment_001")
public class MP0306_AddPositionEquipment_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "PositionEquipment", namespace = "http://schemas.datastream.net/MP_entities/PositionEquipment_001", required = true)
    protected PositionEquipment positionEquipment;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_availability_status")
    protected String confirm_Availability_Status;
    @XmlAttribute(name = "confirmaddlinearreferences")
    protected String confirmaddlinearreferences;
    @XmlAttribute(name = "confirmnewequipmentlength")
    protected String confirmnewequipmentlength;

    /**
     * Gets the value of the positionEquipment property.
     * 
     * @return
     *     possible object is
     *     {@link PositionEquipment }
     *     
     */
    public PositionEquipment getPositionEquipment() {
        return positionEquipment;
    }

    /**
     * Sets the value of the positionEquipment property.
     * 
     * @param value
     *     allowed object is
     *     {@link PositionEquipment }
     *     
     */
    public void setPositionEquipment(PositionEquipment value) {
        this.positionEquipment = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.POSITION_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Availability_Status property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Availability_Status() {
        return confirm_Availability_Status;
    }

    /**
     * Sets the value of the confirm_Availability_Status property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Availability_Status(String value) {
        this.confirm_Availability_Status = value;
    }

    /**
     * Gets the value of the confirmaddlinearreferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmaddlinearreferences() {
        return confirmaddlinearreferences;
    }

    /**
     * Sets the value of the confirmaddlinearreferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmaddlinearreferences(String value) {
        this.confirmaddlinearreferences = value;
    }

    /**
     * Gets the value of the confirmnewequipmentlength property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirmnewequipmentlength() {
        return confirmnewequipmentlength;
    }

    /**
     * Sets the value of the confirmnewequipmentlength property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirmnewequipmentlength(String value) {
        this.confirmnewequipmentlength = value;
    }

}
